Usage
olmm_control(fit = c("nlminb", "ucminf", "optim"),
doFit = TRUE, numGrad = FALSE,
numHess = numGrad, nGHQ = 7L,
start = NULL, restricted = NULL, verbose = FALSE, ...)Arguments
fit
character string. The name of the function to be used for the
optimization.
doFit
logical scalar. When FALSE an unfitted
olmm object is returned. numGrad
logical scalar indicating whether the score function
should be retrieved numerically.
numHess
logical scalar. Indicates whether the Hess matrix for
the variance-covariance matrix should be estimated numerically,
which is an approximation of the observed Fisher information. Must
be TRUE if numGrad is TRUE
nGHQ
a positive integer specifying the number of quadrature
points for the approximation of the marginal Likelihood by numerical
integration.
start
a named numeric vector of initial values for the
parameters. The parameter must be named in exactly in the way as
they appear when the model is fitted.
restricted
a character vector of names of coefficients to be
restricted to the initial values. The argument is ignored in case of
adjacent category models.
verbose
logical scalar. If TRUE verbose output is
generated during the optimization of the parameter estimates.
...
further arguments to be passed to fit.