Learn R Programming

vcrpart (version 0.2-2)

tvcm-control: Control parameters for tvcm.

Description

Various parameters that control aspects for tvcm.

Usage

tvcm_control(minsize = 30, mindev = ifelse(sctest, 0.0, 2.0),
             sctest = FALSE, alpha = 0.05, bonferroni = TRUE,
             trim = 0.1, estfun.args = list(), nimpute = 5, 
             maxnomsplit = 5, maxordsplit = 9, maxnumsplit = 9,
             maxstep = 1e3, maxwidth = 1e9, maxdepth = 1e9,
             lossfun = neglogLik2, ooblossfun = NULL,
             cp = 0.0, dfpar = 0.0, dfsplit = 1.0,
             cv = !sctest, folds = folds_control("kfold", 5),
             prune = cv, papply = mclapply, papply.args = list(),
             center = TRUE, seed = NULL, verbose = FALSE, ...)

Arguments

alpha, bonferroni, trim, estfun.args, nimpute
mindev, cv, folds, prune, center
minsize
numeric (vector). The minimum sum of weights in terminal nodes.
sctest
logical scalar. Defines whether coefficient constancy tests should be used for the variable and node selection in each iteration.
maxnomsplit
integer. For nominal partitioning variables with more the maxnomsplit the categories are ordered an treated as ordinal.
maxordsplit
integer. The maximum number of splits of ordered partitioning variables to be evaluated.
maxnumsplit
integer. The maximum number of splits of numeric partitioning variables to be evaluated.
maxstep
integer. The maximum number of iterations i.e. number of splits to be processed.
maxwidth
integer (vector). The maximum width of the partition(s).
maxdepth
integer (vector). The maximum depth of the partition(s).
lossfun
a function to extract the training error, typically minus two times the negative log likelihood of the fitted model (see neglogLik2).
ooblossfun
a loss function that defines how to compute the validation error during cross-validation. The function will be assigned to the fun argument of oobloss.
cp
numeric scalar. The penalty to be multiplied with the complexity of the model during partitioning. The complexity of the model is defined as the number of coefficients times dfpar plus the number of splits times dfsplit
dfpar
numeric scalar. The degree of freedom per model coefficient. Is used to compute the complexity of the model, see cp.
dfsplit
a numeric scalar. The degree of freedom per split. Is used to compute the complexity of the model, see cp.
papply
(parallel) apply function, defaults to mclapply. The function will parallelize the partition stage and the evaluation of the cross-validation folds as well as the final pruning stage.
papply.args
a list of arguments to be passed to papply.
seed
an integer specifying which seed should be set at the beginning.
verbose
logical. Should information about the fitting process be printed to the screen?
...
further, undocumented arguments to be passed.

Value

  • A list of class tvcm_control containing the control parameters for tvcm.

See Also

tvcolmm_control, tvcglm_control, tvcm, fvcm

Examples

Run this code
tvcm_control()

Run the code above in your browser using DataLab